@@ -22,7 +22,7 @@ class GooglePlusPluginTestCase(BaseGooglePlusTestCase):
         self.assertEqual(CMSPlugin.objects.all().count(), 0)
         google_plus_plugin = add_plugin(self.ph, "GooglePlusActivitiesPlugin", "en", google_user="test",
                                         render_template=DEFAULT_PLUGIN_TEMPLATES[0][0])
-        self.page.publish()
+        self.page.publish(language="en")
         self.assertEqual(CMSPlugin.objects.filter(placeholder__page__publisher_is_draft=False).count(), 1)
         response = self.client.get(self.page.get_absolute_url())
         self.assertEquals(response.status_code, 200)
@@ -32,7 +32,7 @@ class GooglePlusPluginTestCase(BaseGooglePlusTestCase):
         self.assertEqual(CMSPlugin.objects.all().count(), 0)
         google_plus_plugin = add_plugin(self.ph, "GooglePlusActivitiesPlugin", "en", query="test",
                                         render_template=DEFAULT_PLUGIN_TEMPLATES[0][0])
-        self.page.publish()
+        self.page.publish(language='en')
         self.assertEqual(CMSPlugin.objects.filter(placeholder__page__publisher_is_draft=False).count(), 1)
         response = self.client.get(self.page.get_absolute_url())
         self.assertEquals(response.status_code, 200)
